.TH OKit 1 "May 2001" Unix Libraries

.SH NAME

OKeval \- A standard built-ins implementation and RPL interpreter, based on the OKit library.

.SH SYNOPSIS

.BI "OKeval   -h | -H | -H " name " | [options] -f " file " | [options] " code-block ..."

.SH DESCRIPTION

OKeval provides a complete set of basic instructions, and can parse and
execute OKit programs, from the command line, or with the
.B -f
option, from files.

.TP
.B -h :
prints this help and returns

.TP
.B -H :
prints help about supported built-ins

.TP
.B -f :
introduces a file name to be loaded

.SS Options:

A leading '-' followed by one or more characters among

.TP
.BI "c : " *
prints 'echo' comments in read file (started by ##)

.TP
.BI "C : " *
don't print 'echo' comments in read file

.TP
.B r :
prints error reports for each code-block

.TP
.B R :
don't print error reports

.TP
.B s :
prints all stack levels for each code-block

.TP
.B S :
prints all stack levels at the end of execution

.TP
.B p :
prints the first stack level for each code-block

.TP
.B P :
prints the first stack level at the end of execution

.TP
.B 0 :
absolutely quiet execution - usefull for stack preload or verbosity reset

(
.I *
: only meaningfull when used with "
.BI -f " file"
")

.SS Syntax:

Files must contain one code-block per line (use \\ before an \\n to wrap long lines).

Lines whose first character is # are comments, silently ignored, or echoed when the
TWO first characters are # and the -c flag is set.

A code-block is a space-separated list of
.TP
.B numbers   :
+3.141526e00  /  -12345 

.TP
.B strings   :
"hello world"

.TP
.B builtins  :
HELP  /  * 

.TP
.B barewords :
interpretated in order as numbers, then builtins, and strings if everything else failed

.TP
.B lists     :
[ foo bar 10 2 / ] ( any of the above, separated by spaces and inside square brackets )


.SS Built-ins

To get the list of known built-ins, type:

.B	"OKstrevl -H"

For specific help about some built-in, type:

.BI	"OKstrevl -H " built-in_name


Here is a list of currently implemented built-ins, with a short description:

.B !=		
.I Boolean numeric unequality

.B %		
.I Integer remainder

.B &		
.I Bitwise and

.B *		
.I Numeric product

.B +		
.I Numeric addition

.B -		
.I Numeric substraction

.B /		
.I Numeric quotient

.B :		
.I Integer exact division

.B <		
.I Boolean less-than comparison

.B <=		
.I Boolean less-than-or-equal comparison

.B ==		
.I Boolean numeric equality

.B >		
.I Boolean more-than comparison

.B >=		
.I Boolean more-than-or-equal comparison

.B @		
.I Numeric power

.B AND		
.I Boolean conjunction

.B BRK		
.I Breaks a compound object

.B CALV		
.I Execute a variable's content

.B CAT		
.I Concatenes two compound objects

.B CLRSTK	
.I Clears the stack

.B COMP		
.I Boolean type test for a compound object

.B DEC		
.I Numeric 1-decrementation

.B DELV		
.I Undefines a variable

.B DEP		
.I Depth of the stack

.B DROP		
.I Drops the first object on stack

.B DROPN	
.I Drops the N first object on stack

.B DUMP		
.I Prints the stack

.B DUP		
.I Duplicates the first object on stack

.B DUPN		
.I Duplicates the N first objects on stack in order

.B EQL		
.I Tests if two objects are equal

.B ERR		
.I Aborts with specified error

.B EXEC		
.I Execution of a portion of code

.B EXSV		
.I Tells wether a variable is defined

.B FLSE		
.I Always False

.B FLTP		
.I Boolean type test for a float

.B GET		
.I Gets an object by its position in a compound object

.B GRP		
.I Builds a compound object

.B GSZ		
.I Size of a compound object

.B HELP		
.I Returns the description of a builtin

.B IF		
.I 'If then' control structure

.B IFE		
.I 'If then else' control structure

.B INC		
.I Numeric 1-incrementation

.B INTG		
.I Boolean type test for an integer

.B ISDEF	
.I Tells wether first object on stack is not 'undef'

.B LOOP		
.I Loops until code execution return false

.B NOP		
.I Does nothing

.B NOT		
.I Boolean negation

.B OBJ		
.I Parse a string into objects

.B OR		
.I Boolean disjunction

.B PEEK		
.I Gets the object on level stack[0]

.B POKE		
.I Puts the object stack[1] on level stack[0]

.B PONG		
.I Inserts the object stack[1] on level stack[0]

.B PRINT	
.I Prints an object

.B PRINTLN	
.I Prints an object and \\\\n

.B PRINTSTR	
.I Prints a string with \\\\[abfnrt] converted

.B RCLV		
.I Recalls a variable's value

.B RND		
.I Rounds a number

.B ROLSTK	
.I Rolls down the last object on stack, if any

.B ROTSTK	
.I Rolls up the first object on stack, if any

.B STOV		
.I Stores a value in a variable

.B STR		
.I Makes a string from an object

.B STRG		
.I Boolean type test for a string

.B SWAP		
.I Swaps the two first objects on stack

.B TRUE		
.I Always True

.B UNDEF	
.I Pushes 'undef'

.B VARS		
.I Lists all existing variables

.B ^		
.I Bitwise xor

.B |		
.I Bitwise or

.B ~		
.I Bitwise 1-complement




.SH AUTHOR

.BI Author:   " Yann LANDRIN-SCHWEITZER"

.BI Contact:  " varkhan@free.fr"

.BI Homepage: " http://varkhan.free.fr/"




.SH LICENSE

This library is free software;  you can redistribute it and/or modify it
under  the terms of the  GNU Lesser General Public License  as published
by the  Free Software Foundation;  either version 2.1 of the License, or
(at your option) any later version.


This  library  is  distributed  in  the hope that it will be useful, but
WITHOUT   ANY   WARRANTY;   without   even   the   implied  warranty  of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
General Public License for more details.


You should have received a copy of the GNU Lesser General Public License
along with this library;  if not, write to the Free Software Foundation,
Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

